==> plugin-android-2.3.1-sources.jar: com/zoyi/channel/plugin/android/model/rest/Message.java <==
package com.zoyi.channel.plugin.android.model.rest;

import com.zoyi.channel.plugin.android.model.interfaces.ChannelModel;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Message implements ChannelModel {
  private String id;
  private String channelId;
  private String chatType;
  private String chatId;
  private String personType;
  private String personId;
  private String message;
  private Long createdAt;
  private String requestId;
  private File file;
  private WebPage webPage;
  private Log log;
  private BotOption botOption;

  public Message() {}

  public Message(String message) {
    this.message = message;
  }

  public Message(String message, long createdAt) {
    this.message = message;
    this.createdAt = createdAt;
  }

  public String getId() {
    return id;
  }

  public String getChannelId() {
    return channelId;
  }

  public String getChatType() {
    return chatType;
  }

  public String getChatId() {
    return chatId;
  }

  public String getPersonType() {
    return personType;
  }

  public String getPersonId() {
    return personId;
  }

  public String getMessage() {
    return message;
  }

  public Long getCreatedAt() {
    return createdAt;
  }

  public String getRequestId() {
    return requestId;
  }

  public File getFile() {
    return file;
  }

  public WebPage getWebPage() {
    return webPage;
  }

  public boolean hasContent() {
    return file != null || webPage != null;
  }

  public final static String CLASSNAME = "Message";

  public boolean isUserMessage() {
    return "User".equals(personType) || "Veil".equals(personType);
  }

  public Log getLog() {
    return log;
  }

  public void setBotOption(BotOption botOption) {
    this.botOption = botOption;
  }

  public BotOption getBotOption() {
    return botOption;
  }
}

==> plugin-android-3.0.0-sources.jar: com/zoyi/channel/plugin/android/model/rest/Message.java <==
package com.zoyi.channel.plugin.android.model.rest;

import android.text.SpannableStringBuilder;

import com.zoyi.channel.plugin.android.model.interfaces.ChannelModel;

/**
 * Created by mika on 2016. 12. 6..
 */
public class Message implements ChannelModel {
  private String id;
  private String channelId;
  private String chatType;
  private String chatId;
  private String personType;
  private String personId;
  private String message;
  private String messageV2;
  private Long createdAt;
  private String requestId;
  private File file;
  private WebPage webPage;
  private Log log;
  private BotOption botOption;
  private SpannableStringBuilder formattedSpanMessage;
  private String formattedStringMessage;

  public Message() {}

  public Message(String message) {
    this.message = message;
  }

  public Message(String message, long createdAt) {
    this.message = message;
    this.createdAt = createdAt;
  }

  public String getId() {
    return id;
  }

  public String getChannelId() {
    return channelId;
  }

  public String getChatType() {
    return chatType;
  }

  public String getChatId() {
    return chatId;
  }

  public String getPersonType() {
    return personType;
  }

  public String getPersonId() {
    return personId;
  }

  public String getMessage() {
    if (messageV2 != null) {
      return messageV2;
    } else {
      return message;
    }
  }

  public Long getCreatedAt() {
    return createdAt;
  }

  public String getRequestId() {
    return requestId;
  }

  public File getFile() {
    return file;
  }

  public WebPage getWebPage() {
    return webPage;
  }

  public boolean hasContent() {
    return file != null || webPage != null;
  }

  public final static String CLASSNAME = "Message";

  public boolean isUserMessage() {
    return "User".equals(personType) || "Veil".equals(personType);
  }

  public Log getLog() {
    return log;
  }

  public void setBotOption(BotOption botOption) {
    this.botOption = botOption;
  }

  public BotOption getBotOption() {
    return botOption;
  }

  public SpannableStringBuilder getFormattedSpanMessage() {
    return formattedSpanMessage;
  }

  public String getFormattedStringMessage() {
    return formattedStringMessage;
  }

  public void setFormattedSpanMessage(SpannableStringBuilder formattedSpanMessage) {
    this.formattedSpanMessage = formattedSpanMessage;
  }

  public void setFormattedStringMessage(String formattedStringMessage) {
    this.formattedStringMessage = formattedStringMessage;
  }
}
